@@ -1,7 +1,7 @@
-use nom_http;
+use crate::nom_http;
 
-use structs::CentrifugeError;
-use structs::http::Request;
+use crate::structs::CentrifugeError;
+use crate::structs::http::Request;
 
 pub fn extract(remaining: &[u8]) -> Result<Request, CentrifugeError> {
     if let Ok((_remaining, (request, headers))) = nom_http::request(remaining) {
