@@ -13,7 +13,7 @@ use crate::structs::udp::UDP;
 
 pub fn parse(remaining: &[u8]) -> Result<(udp::UdpHeader, UDP), CentrifugeError> {
     if let Ok((remaining, udp_hdr)) = udp::parse_udp_header(remaining) {
-        let inner = match extract(&udp_hdr, remaining) {
+        let inner = match extract(udp_hdr, remaining) {
             Ok(x) => x,
             Err(_) => unknown(remaining),
         };
@@ -24,7 +24,7 @@ pub fn parse(remaining: &[u8]) -> Result<(udp::UdpHeader, UDP), CentrifugeError>
 }
 
 #[inline]
-pub fn extract(udp_hdr: &UdpHeader, remaining: &[u8]) -> Result<UDP, CentrifugeError> {
+pub fn extract(udp_hdr: UdpHeader, remaining: &[u8]) -> Result<UDP, CentrifugeError> {
     if remaining.is_empty() {
         Ok(UDP::Binary(Vec::new()))
     } else if udp_hdr.dest_port == 53 || udp_hdr.source_port == 53 {
