@@ -1,27 +1,33 @@
-use std::thread;
-use std::sync::{mpsc, Arc, Mutex};
-
 mod cli;
 mod fmt;
+
 use crate::cli::Args;
+use env_logger::Env;
 use sniffglue::centrifuge;
 use sniffglue::errors::*;
 use sniffglue::link::DataLink;
 use sniffglue::sandbox;
 use sniffglue::sniff;
 use sniffglue::structs;
-
+use std::io::stdout;
+use std::sync::{mpsc, Arc, Mutex};
+use std::thread;
 use structopt::StructOpt;
 
-fn run() -> Result<()> {
-    // this goes before the sandbox so logging is available
-    env_logger::init();
+fn main() -> Result<()> {
+    env_logger::init_from_env(Env::default()
+        .default_filter_or("sniffglue=warn"));
 
-    sandbox::activate_stage1()
+    let mut args = Args::from_args();
+
+    if let Some(shell) = args.gen_completions {
+        Args::clap().gen_completions_to("sniffglue", shell, &mut stdout());
+        return Ok(());
+    }
+
+    sandbox::activate_stage1(args.insecure_disable_seccomp)
         .context("Failed to init sandbox stage1")?;
 
-    let args = Args::from_args();
-
     let device = if let Some(dev) = args.device {
         dev
     } else {
@@ -37,12 +43,19 @@ fn run() -> Result<()> {
         fmt::Layout::Compact
     };
 
-    let threads = args.threads.unwrap_or_else(num_cpus::get);
-
     let colors = atty::is(atty::Stream::Stdout);
     let config = fmt::Config::new(layout, args.verbose, colors);
 
-    let cap = if !args.read {
+    let cap = if args.read {
+        if args.threads.is_none() {
+            debug!("Setting thread default to 1 due to -r");
+            args.threads = Some(1);
+        }
+
+        let cap = sniff::open_file(&device)?;
+        eprintln!("Reading from file: {:?}", device);
+        cap
+    } else {
         let cap = sniff::open(&device, &sniff::Config {
             promisc: args.promisc,
             immediate_mode: true,
@@ -51,19 +64,18 @@ fn run() -> Result<()> {
         let verbosity = config.filter().verbosity;
         eprintln!("Listening on device: {:?}, verbosity {}/4", device, verbosity);
         cap
-    } else {
-        let cap = sniff::open_file(&device)?;
-        eprintln!("Reading from file: {:?}", device);
-        cap
     };
 
+    let threads = args.threads.unwrap_or_else(num_cpus::get);
+    debug!("Using {} threads", threads);
+
     let datalink = DataLink::from_linktype(cap.datalink())?;
 
     let filter = config.filter();
     let (tx, rx) = mpsc::sync_channel(256);
     let cap = Arc::new(Mutex::new(cap));
 
-    sandbox::activate_stage2()
+    sandbox::activate_stage2(args.insecure_disable_seccomp)
         .context("Failed to init sandbox stage2")?;
 
     for _ in 0..threads {
@@ -75,7 +87,7 @@ fn run() -> Result<()> {
             loop {
                 let packet = {
                     let mut cap = cap.lock().unwrap();
-                    cap.next()
+                    cap.next_pkt()
                 };
 
                 if let Ok(Some(packet)) = packet {
@@ -84,6 +96,7 @@ fn run() -> Result<()> {
                         tx.send(packet).unwrap()
                     }
                 } else {
+                    debug!("End of packet stream, shutting down reader thread");
                     break;
                 }
             }
@@ -98,13 +111,3 @@ fn run() -> Result<()> {
 
     Ok(())
 }
-
-fn main() {
-    if let Err(err) = run() {
-        eprintln!("Error: {}", err);
-        for cause in err.iter_chain().skip(1) {
-            eprintln!("Because: {}", cause);
-        }
-        std::process::exit(1);
-    }
-}
