@@ -2,8 +2,6 @@ use crate::errors::*;
 use serde::Deserialize;
 use std::fs;
 use std::path::Path;
-use toml;
-use dirs;
 
 #[derive(Debug, Default, Deserialize, PartialEq)]
 pub struct Config {
@@ -22,7 +20,7 @@ pub fn find() -> Option<String> {
         String::from("/usr/local/etc/sniffglue.conf"),
     ];
 
-    if let Some(home) = dirs::config_dir() {
+    if let Some(home) = dirs_next::config_dir() {
         let path = home.join(Path::new("sniffglue.conf"));
 
         if let Some(path) = path.to_str() {
